BetweenCondition class final

Filter matching values between the bounds.

Constructors

BetweenCondition({required int property, required Object? lower, required Object? upper, double epsilon = Filter.epsilon, bool caseSensitive = true})
Filters the results to only include objects where the property is between lower and upper.
const

Properties

caseSensitive → bool
Should Strings be case sensitive?
final
epsilon → double
The maximum difference between two floating point numbers to be considered equal.
final
hashCode → int
The hash code for this object.
no setterinherited
lower → Object?
The lower bound.
final
property → int
Index of the property that should be matched.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
upper → Object?
The upper bound.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited