DatabaseUniverseIndexSchema class

The schema of an index in DatabaseUniverse.

Properties

hash → bool
Whether this index should be hashed.
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
The name of the index.
final
properties → List<String>
The properties of the index.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unique → bool
Whether this index is unique.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited