DatabaseUniversePropertySchema class

The schema of a property in DatabaseUniverse.

Properties

enumMap → Map<String, dynamic>?
If this property is an enum, this map contains the enum values.
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
The name of the property.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
target → String?
If this property contains object(s), this is the name of the embedded collection.
final
type → DatabaseUniverseType
The type of the property.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited