DatabaseUniverseQuery<T> class abstract

Querying is how you find records that match certain conditions.

It is important to call close() when you are done with a query, otherwise you will leak resources.

Available extensions

Constructors

DatabaseUniverseQuery()

Properties

databaseUniverse → DatabaseUniverse
The corresponding DatabaseUniverse instance.
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

average() → double

Available on DatabaseUniverseQuery<T?>, provided by the QueryNumAggregation extension

Calculates the average of all values. This only works for numeric values.
averageAsync() → Future<double>

Available on DatabaseUniverseQuery<T?>, provided by the QueryNumAggregation extension

Calculates the average of all values. This only works for numeric values.
close() → void
Release all resources associated with this query.
count() → int
Finds the smallest value matching the query. Null values are considered smaller than all other values.
countAsync() → Future<int>

Available on DatabaseUniverseQuery<T>, provided by the QueryAsync extension

Count how many objects match the query.
deleteAll({int? offset, int? limit}) → int
Delete all objects that match this query. Returns the number of deleted objects.
deleteFirst({int? offset}) → bool
Delete the first object that matches this query. Returns whether an object has been deleted.
exportJson({int? offset, int? limit}) → List<Map<String, dynamic>>
Export the results of this query as json.
findAll({int? offset, int? limit}) → List<T>
Find all objects that match this query.
findAllAsync({int? offset, int? limit}) → Future<List<T>>

Available on DatabaseUniverseQuery<T>, provided by the QueryAsync extension

Find all objects that match this query.
findFirst({int? offset}) → T?
Find the first object that matches this query or null if no object matches.
findFirstAsync({int? offset}) → Future<T?>

Available on DatabaseUniverseQuery<T>, provided by the QueryAsync extension

Find the first object that matches this query or null if no object matches.
isEmpty() → bool
Yields true if there are no objects that match the query.
isEmptyAsync() → Future<bool>

Available on DatabaseUniverseQuery<T>, provided by the QueryAsync extension

Yields true if there are no objects that match the query.
max() → DateTime?

Available on DatabaseUniverseQuery<T>, provided by the QueryDateAggregation extension

Finds the largest value matching the query.
max() → T?

Available on DatabaseUniverseQuery<T?>, provided by the QueryNumAggregation extension

Finds the largest value matching the query.
max() → T?

Available on DatabaseUniverseQuery<T?>, provided by the QueryStringAggregation extension

Finds the largest value matching the query.
maxAsync() → Future<DateTime?>

Available on DatabaseUniverseQuery<T>, provided by the QueryDateAggregation extension

Finds the largest value matching the query.
maxAsync() → Future<T?>

Available on DatabaseUniverseQuery<T?>, provided by the QueryNumAggregation extension

Finds the largest value matching the query.
maxAsync() → Future<T?>

Available on DatabaseUniverseQuery<T?>, provided by the QueryStringAggregation extension

Finds the largest value matching the query.
min() → DateTime?

Available on DatabaseUniverseQuery<T>, provided by the QueryDateAggregation extension

Finds the smallest value matching the query. Null values are considered smaller than all other values.
min() → T?

Available on DatabaseUniverseQuery<T?>, provided by the QueryNumAggregation extension

Finds the smallest value matching the query. Null values are considered smaller than all other values.
min() → T?

Available on DatabaseUniverseQuery<T?>, provided by the QueryStringAggregation extension

Finds the smallest value matching the query. Null values are considered smaller than all other values.
minAsync() → Future<DateTime?>

Available on DatabaseUniverseQuery<T>, provided by the QueryDateAggregation extension

Finds the smallest value matching the query. Null values are considered smaller than all other values.
minAsync() → Future<T?>

Available on DatabaseUniverseQuery<T?>, provided by the QueryNumAggregation extension

Finds the smallest value matching the query. Null values are considered smaller than all other values.
minAsync() → Future<T?>

Available on DatabaseUniverseQuery<T?>, provided by the QueryStringAggregation extension

Finds the smallest value matching the query. Null values are considered smaller than all other values.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sum() → T

Available on DatabaseUniverseQuery<T?>, provided by the QueryNumAggregation extension

Calculates the sum of all values. This only works for numeric values.
sumAsync() → Future<T>

Available on DatabaseUniverseQuery<T?>, provided by the QueryNumAggregation extension

Calculates the sum of all values. This only works for numeric values.
toString() → String
A string representation of this object.
inherited
updateProperties(Map<int, dynamic> changes, {int? offset, int? limit}) → int
This is a low level method to update objects.
watch({bool fireImmediately = false, int? offset, int? limit}) → Stream<List<T>>
Create a watcher that yields the results of this query whenever its results have (potentially) changed.
watchLazy({bool fireImmediately = false}) → Stream<void>
Watch the query for changes. If fireImmediately is true, an event will be fired immediately.

Operators

operator ==(Object other) → bool
The equality operator.
inherited