DatabaseUniverseSchema class

The schema of a collection in DatabaseUniverse.

This class represents the structure of a collection. This includes the collection name, the properties and indexes.

Properties

embedded → bool
Whether this collection is embedded in another object.
final
hashCode → int
The hash code for this object.
no setterinherited
idName → String?
The name of the id property. Only String id properties are defined in properties.
final
indexes → List<DatabaseUniverseIndexSchema>
The indexes of this collection.
final
name → String
The name of the collection.
final
properties → List<DatabaseUniversePropertySchema>
The properties of this collection.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getPropertyByIndex(int index) → DatabaseUniversePropertySchema
Get the property schema by its index.
getPropertyIndex(String property) → int
Get the index of a property in this schema.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited