DistinctProperty class

Property used to filter duplicate values.

Constructors

DistinctProperty({required int property, bool caseSensitive = true})
Create a distinct property.
const

Properties

caseSensitive → bool
Should Strings be case sensitive?
final
hashCode → int
The hash code for this object.
no setterinherited
property → int
Index of the property used to determine distinct values.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited