EnumValue class

Annotation to specify how an enum property should be serialized.

Annotations
  • @Target.new({TargetKind.field, TargetKind.getter})

Constructors

EnumValue()
Annotation to specify how an enum property should be serialized.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited