IsNullCondition class final

Filter matching values that are null.

Constructors

IsNullCondition({required int property})
Filters the results to only include objects where the property is null.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
property → int
Index of the property that should be null.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited