LessOrEqualCondition class final

Filter matching values smaller than or equal to the bound.

Constructors

LessOrEqualCondition({required int property, required Object? value, double epsilon = Filter.epsilon, bool caseSensitive = true})
Filters the results to only include objects where the property is less than or equal to value.
const

Properties

caseSensitive → bool
Should Strings be case sensitive?
final
epsilon → double
The maximum difference between two floating point numbers to be considered equal.
final
hashCode → int
The hash code for this object.
no setterinherited
property → int
Index of the property that should be matched.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → Object?
The value to match against.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited