MatchesCondition class final

Filter matching String values matching the wildcard.

Constructors

MatchesCondition({required int property, required String wildcard, bool caseSensitive = true})
Filters the results to only include objects where the property matches the wildcard.
const

Properties

caseSensitive → bool
Should Strings be case sensitive?
final
hashCode → int
The hash code for this object.
no setterinherited
property → int
Index of the property that should be matched.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
wildcard → String
The wildcard to match against.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited