QueryDateAggregation<T extends DateTime?> extension

Aggregation operations for date queries.

on

Methods

max() → DateTime?

Available on DatabaseUniverseQuery<T>, provided by the QueryDateAggregation extension

Finds the largest value matching the query.
maxAsync() → Future<DateTime?>

Available on DatabaseUniverseQuery<T>, provided by the QueryDateAggregation extension

Finds the largest value matching the query.
min() → DateTime?

Available on DatabaseUniverseQuery<T>, provided by the QueryDateAggregation extension

Finds the smallest value matching the query. Null values are considered smaller than all other values.
minAsync() → Future<DateTime?>

Available on DatabaseUniverseQuery<T>, provided by the QueryDateAggregation extension

Finds the smallest value matching the query. Null values are considered smaller than all other values.