QueryExecuteDateAggregation<OBJ> extension

Aggregation operations for date query builders.

on

Methods

max() → DateTime?

Available on QueryBuilder<OBJ, DateTime?, QAfterProperty>, provided by the QueryExecuteDateAggregation extension

Finds the largest value matching the query.
maxAsync() → Future<DateTime?>

Available on QueryBuilder<OBJ, DateTime?, QAfterProperty>, provided by the QueryExecuteDateAggregation extension

Finds the largest value matching the query.
min() → DateTime?

Available on QueryBuilder<OBJ, DateTime?, QAfterProperty>, provided by the QueryExecuteDateAggregation extension

Finds the smallest value matching the query. Null values are considered smaller than all other values.
minAsync() → Future<DateTime?>

Available on QueryBuilder<OBJ, DateTime?, QAfterProperty>, provided by the QueryExecuteDateAggregation extension

Finds the smallest value matching the query. Null values are considered smaller than all other values.