QueryExecuteStringAggregation<OBJ> extension

Aggregation operations for string query builders.

on

Methods

max() → String?

Available on QueryBuilder<OBJ, String?, QAfterProperty>, provided by the QueryExecuteStringAggregation extension

Finds the largest value matching the query.
maxAsync() → Future<String?>

Available on QueryBuilder<OBJ, String?, QAfterProperty>, provided by the QueryExecuteStringAggregation extension

Finds the largest value matching the query.
min() → String?

Available on QueryBuilder<OBJ, String?, QAfterProperty>, provided by the QueryExecuteStringAggregation extension

Finds the smallest value matching the query. Null values are considered smaller than all other values.
minAsync() → Future<String?>

Available on QueryBuilder<OBJ, String?, QAfterProperty>, provided by the QueryExecuteStringAggregation extension

Finds the smallest value matching the query. Null values are considered smaller than all other values.