StartsWithCondition class final

Filter matching String values starting with the prefix.

Constructors

StartsWithCondition({required int property, required String value, bool caseSensitive = true})
Filters the results to only include objects where the property starts with value.
const

Properties

caseSensitive → bool
Should Strings be case sensitive?
final
hashCode → int
The hash code for this object.
no setterinherited
property → int
Index of the property that should be matched.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → String
The prefix to match against.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited