JSWindow class

Available extensions
Annotations

Constructors

JSWindow()

Properties

database_universe → JSDatabaseUniverse

Available on JSWindow, provided by the JSWIndowX extension

no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
WebAssembly → JSWasm

Available on JSWindow, provided by the JSWIndowX extension

no setter

Methods

fetch(String url) → JSAny

Available on JSWindow, provided by the JSWIndowX extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited